==> bfilter-0.10.1.tar.gz: bfilter-0.10.1/main/confio/ContentFilters.cpp <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "pch.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "ContentFilters.h"
#include "RegexFilterDescriptor.h"
#include <algorithm>

using namespace std;

struct ContentFilters::OrderComparator
{
	OrderComparator() {}
	
	bool operator()(
		IntrusivePtr<RegexFilterDescriptor const> const& lhs,
		IntrusivePtr<RegexFilterDescriptor const> const& rhs) {
		return lhs->order() < rhs->order();
	}
};


ContentFilters::ContentFilters()
{
}

ContentFilters::ContentFilters(ContentFilters const& other)
:	m_filters(other.m_filters)
{
}

ContentFilters::~ContentFilters()
{
}

ContentFilters&
ContentFilters::operator=(ContentFilters const& other)
{
	m_filters = other.m_filters;
	return *this;
}

ContentFilters::FilterList::iterator
ContentFilters::find(FilterPtr const& filter)
{
	return std::find(m_filters.begin(), m_filters.end(), filter);
}

void
ContentFilters::sortByOrder()
{
	std::stable_sort(m_filters.begin(), m_filters.end(), OrderComparator());
}

void
ContentFilters::swap(ContentFilters& other)
{
	m_filters.swap(other.m_filters);
}

==> bfilter_1.0.6.orig.tar.gz: bfilter-1.0.6/main/confio/ContentFilters.cpp <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "pch.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "ContentFilters.h"
#include "RegexFilterDescriptor.h"
#include <algorithm>

using namespace std;

struct ContentFilters::OrderComparator
{
	OrderComparator() {}
	
	bool operator()(
		IntrusivePtr<RegexFilterDescriptor const> const& lhs,
		IntrusivePtr<RegexFilterDescriptor const> const& rhs) {
		return lhs->order() < rhs->order();
	}
};


ContentFilters::ContentFilters()
{
}

ContentFilters::ContentFilters(ContentFilters const& other)
:	m_filters(other.m_filters)
{
}

ContentFilters::~ContentFilters()
{
}

ContentFilters&
ContentFilters::operator=(ContentFilters const& other)
{
	m_filters = other.m_filters;
	return *this;
}

ContentFilters::FilterList::iterator
ContentFilters::find(FilterPtr const& filter)
{
	return std::find(m_filters.begin(), m_filters.end(), filter);
}

bool
ContentFilters::hasValidFilters() const
{
	FilterList::const_iterator it = m_filters.begin();
	FilterList::const_iterator const end = m_filters.end();
	for (; it != end; ++it) {
		if ((*it)->isValid()) {
			return true;
		}
	}
	return false;
}

void
ContentFilters::sortByOrder()
{
	std::stable_sort(m_filters.begin(), m_filters.end(), OrderComparator());
}

void
ContentFilters::swap(ContentFilters& other)
{
	m_filters.swap(other.m_filters);
}
